@@ -1,3 +1,9 @@
+// SPDX-FileCopyrightText: 2024 Christina Sørensen
+// SPDX-License-Identifier: EUPL-1.2
+//
+// SPDX-FileCopyrightText: 2023-2024 Christina Sørensen, eza contributors
+// SPDX-FileCopyrightText: 2014 Benjamin Sago
+// SPDX-License-Identifier: MIT
 use crate::theme::lsc::Pair;
 use nu_ansi_term::{Color::*, Style};
 use serde::{Deserialize, Serialize};
@@ -244,6 +250,7 @@ field_accessors!(
 );
 
 #[rustfmt::skip]
+#[allow(unused)]
 #[derive(Clone, Copy, Debug, Eq, Default, PartialEq, Serialize, Deserialize)]
 pub struct Links {
     pub normal: Option<Style>,           // lc
